API Reference
=============

This page gives an overview of all the public autumn classes, functions and methods. Everything that intended for public use is exposed in the ``autumn.*`` or ``autumn.aio.*`` namespaces.

.. currentmodule:: autumn

Client
------

.. autoclass:: autumn.client.Client
   :members:
   :undoc-members:

.. autoclass:: autumn.aio.client.AsyncClient
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

API Features
------------

Customers
^^^^^^^^^

.. autoclass:: autumn.customers.Customers
   :members:
   :undoc-members:

Features
^^^^^^^^

.. autoclass:: autumn.features.Features
   :members:
   :undoc-members:

Products
^^^^^^^^

.. autoclass:: autumn.products.Products
   :members:
   :undoc-members:

Entities
^^^^^^^^

.. autoclass:: autumn.entities.Entities
   :members:
   :undoc-members:

Exceptions
----------

.. autoclass:: autumn.error.AutumnError
   :members:
   :undoc-members:

.. autoclass:: autumn.error.AutumnValidationError
   :members:
   :undoc-members:

.. autoclass:: autumn.error.AutumnHTTPError
   :members:
   :undoc-members:
